@@ -53,7 +53,7 @@ def request_day_data_paquet(url, me_ts, ssj):
         print('no data')
     return dataframe
 
-def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pkl_filename_suffix=None, refetch_all=True,daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None,ssj_against='USDT', exchange = 'binance'):
+def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pkl_filename_suffix='_daily_returns.pkl', refetch_all=True,daily_crypto_starting_day='2012-01-01', daily_crypto_ending_day=None,ssj_against='USDT', exchange = 'binance'):
     dates_stub = daily_crypto_starting_day.strftime('%d_%b_%Y') + '_' + daily_crypto_ending_day.strftime('%d_%b_%Y')
     pickle_saving_path = local_root_directory+ssj+'_'+dates_stub+daily_return_pkl_filename_suffix
     if refetch_all:
@@ -95,8 +95,10 @@ def fetch_crypto_daily_data(ssj=None, local_root_directory=None, daily_return_pk
         dataframe = dataframe[dataframe.index <= daily_crypto_ending_day]
         print('size filtered after '+str(daily_crypto_starting_day))
         print(dataframe.shape)
+        print(f'writing {pickle_saving_path}')
         dataframe.to_pickle(pickle_saving_path)
     else:
+        print(f'reading {pickle_saving_path}')
         dataframe = pd.read_pickle(pickle_saving_path)
     return dataframe
 
