@@ -922,6 +922,7 @@ class RealTimeSignalEnsemblingParalleLauncher():
         updated_df = updated_df.set_index(updated_df['date'])
         updated_df = updated_df.drop(columns=['date'])
         self.day_signal_df = updated_df.copy()
+        print('last update daily signal df {}',self.day_signal_df.tail())
         return filename
 
     def update_signal_minute_dataframe(self):
@@ -1076,9 +1077,11 @@ class RealTimeSignalEnsemblingParalleLauncher():
 
         print(f'day signal shape {self.day_signal_np.shape}')
         if len(self.day_signal_np.shape)>1 and len(self.day_signal_np)>3:
-            #print('last three daily signals')
-            #print(self.day_signal_np[-3:])
-            print('forward filling the triggered daily signals ')
+            print(f'last three daily signals before forward filling {self.day_signal_np[-3:]}')
+            print(f'forward filling the triggered day signals {len(self.day_calib_signals_list)} ')
+            print(f'trigger map day signal size {len(trigger_results)} ')
+            print(f'daily triggered results {trigger_results}')
+
             counter = 0
             for meArg in self.day_calib_signals_list:
                 triggered = trigger_results[counter]
@@ -1089,9 +1092,10 @@ class RealTimeSignalEnsemblingParalleLauncher():
                             self.day_signal_np[row_idx, signal_counter] = self.day_signal_np[row_idx-1, signal_counter]
                 else :
                     if np.isnan(self.day_signal_np[-1, signal_counter]):
-                        self.day_signal_np[-1, signal_counter] = 0
+                        self.day_signal_np[-1, signal_counter] = 0.
                 counter = counter + 1
-            #updating the day signal df
+            print(f'last three daily signals after forward filling {self.day_signal_np[-3:]}')
+
             self.update_signal_day_dataframe()
             last_day_ts, discrete_day_signal = self.day_signals_ia_mixing()
             self.update_day_aggregated_signal(last_day_ts, discrete_day_signal)
@@ -1136,9 +1140,10 @@ class RealTimeSignalEnsemblingParalleLauncher():
             self.minute_signal_np = np.vstack((self.minute_signal_np, new_data_sig))
 
         if len(self.minute_signal_np.shape)>1 and len(self.minute_signal_np)>3:
-            #print('last three signals')
-            #print(self.minute_signal_np[-3:])
-            print('forward filling the triggered minute signals ')
+            print(f'last three minute signals before forward filling {self.minute_signal_np[-3:]}')
+            print(f'forward filling the triggered minute signals {len(self.min_calib_signals_list)} ')
+            print(f'trigger map minute signal size {len(trigger_results)} ')
+
             counter = 0
             for meArg in self.min_calib_signals_list:
                 triggered = trigger_results[counter]
@@ -1149,8 +1154,9 @@ class RealTimeSignalEnsemblingParalleLauncher():
                             self.minute_signal_np[row_idx, signal_counter] = self.minute_signal_np[row_idx-1, signal_counter]
                 else :
                     if np.isnan(self.minute_signal_np[-1, signal_counter]):
-                        self.minute_signal_np[-1, signal_counter] = 0
+                        self.minute_signal_np[-1, signal_counter] = 0.
                 counter = counter + 1
+            print(f'last three minute signals after forward filling {self.minute_signal_np[-3:]}')
             self.update_signal_minute_dataframe()
             last_minute_ts, discrete_minute_signal = self.minute_signals_ia_mixing()
             self.update_minute_aggregated_signal(last_minute_ts, discrete_minute_signal)
@@ -1161,8 +1167,6 @@ class RealTimeSignalEnsemblingParalleLauncher():
         new_minute_sig_dic = {'ts':last_minute_ts,'minute_discrete_sig':discrete_minute_signal}
         self.on_the_fly_discrete_minute_signals.append(new_minute_sig_dic)
 
-
-
     def day_signals_ia_mixing(self):
         print('day signal shape')
         print(self.day_signal_np.shape)
@@ -1170,9 +1174,8 @@ class RealTimeSignalEnsemblingParalleLauncher():
         last_day_ts =  self.day_signal_np[-1, 0]
         last_day_signals = self.day_signal_np[-1, len(self.generic_columns):]
         nb_nan_signals = np.isnan(last_day_signals).sum()
-        print('still '+str(nb_nan_signals)+' not triggered day signals')
-        print('last daily alphas signal')
-        print(last_day_signals)
+        print(f'still {nb_nan_signals} not triggered day signals')
+        print(f'last daily alphas signal {last_day_signals}')
         print('discretizing the signal')
         if  self.day_signal_np.shape[0]> self.daily_ia_lookback_window + 1:
             discrete_signals = self.daily_apply_standard_mean_two_states_discretization_last_signal()
@@ -1187,9 +1190,8 @@ class RealTimeSignalEnsemblingParalleLauncher():
         last_minute_ts =  self.minute_signal_np[-1, 0]
         last_minute_signals = self.minute_signal_np[-1, len(self.generic_columns):]
         nb_nan_signals = np.isnan(last_minute_signals).sum()
-        print('still '+str(nb_nan_signals)+' not triggered minute signals')
-        print('last minute alphas signal')
-        print(last_minute_signals)
+        print(f'still {nb_nan_signals} not triggered minute signals')
+        print(f'last minute alphas signal {last_minute_signals}')
         print('discretizing the signal')
         if  self.minute_signal_np.shape[0]> self.minutely_ia_lookback_window + 1:
             discrete_signals = self.minutely_apply_standard_mean_two_states_discretization_last_signal()
