@@ -554,7 +554,7 @@ def find_best_two_states_discretization(y_pred, y, seed = 42, number_per_year =
                                                               transaction_cost=False,
                                                               print_turnover=False)
         sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=number_per_year, from_ret=True)
-        return sharpe_strat
+        return -sharpe_strat
 
     np.random.seed(seed)
 
@@ -602,7 +602,7 @@ def find_best_two_states_discretization_lo(y_pred, y, seed = 42, number_per_year
                                                               transaction_cost=False,
                                                               print_turnover=False)
         sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=number_per_year, from_ret=True)
-        return sharpe_strat
+        return -sharpe_strat
 
     np.random.seed(seed)
     # Optimize f
@@ -642,20 +642,30 @@ def find_best_three_states_discretization(y_pred, y, seed = 42, number_per_year=
                                                               transaction_cost=False,
                                                               print_turnover=False)
         sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=number_per_year, from_ret=True)
-        return sharpe_strat
+        return -sharpe_strat
 
     np.random.seed(seed)
     # Optimize f
-    w__ = minimize(
-        f_to_optimize,
-        w0,
-        method='SLSQP',
-        #constraints=[const_sum],
-        bounds=const_ind
-    ).x
+    lower_quantile_threshold = 0.3
+    upper_quantile_threshold = 0.7
+
+    try:
+        w__ = minimize(
+            f_to_optimize,
+            w0,
+            method='SLSQP',
+            # constraints=[const_sum],
+            bounds=const_ind
+        ).x
+        lower_quantile_threshold = w__[0]
+        upper_quantile_threshold = w__[1]
+    except Exception:
+        print('trouble converging')
+
+
+
+
 
-    lower_quantile_threshold = w__[0]
-    upper_quantile_threshold = w__[1]
     y_pred_discrete = discretize_three_states(y_pred, upper_quantile_threshold=upper_quantile_threshold,
                                  lower_quantile_threshold=lower_quantile_threshold)
     perf_df = signal_utility.reconstitute_prediction_perf(y_pred=y_pred_discrete, y_true=y,
@@ -686,7 +696,7 @@ def find_best_three_states_discretization_lo(y_pred, y, seed = 42, number_per_ye
                                                               transaction_cost=False,
                                                               print_turnover=False)
         sharpe_strat = metrics.sharpe(perf_df['perf_return'].dropna(), period=number_per_year, from_ret=True)
-        return sharpe_strat
+        return -sharpe_strat
 
     np.random.seed(seed)
     # Optimize f
